==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FunnelSliceClickedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceClickedEventArgsDescription } from "./FunnelSliceClickedEventArgsDescription";
/**
 * @hidden
 */
var FunnelSliceClickedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunnelSliceClickedEventArgsDescriptionMetadata, _super);
    function FunnelSliceClickedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelSliceClickedEventArgsDescriptionMetadata.b = function (a) {
        if (FunnelSliceClickedEventArgsDescriptionMetadata.a == null) {
            FunnelSliceClickedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelSliceClickedEventArgsDescriptionMetadata.c(FunnelSliceClickedEventArgsDescriptionMetadata.a);
        }
        if (a.j(FunnelSliceClickedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(FunnelSliceClickedEventArgsDescriptionMetadata.a);
    };
    FunnelSliceClickedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("Bounds", "Rect");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    FunnelSliceClickedEventArgsDescriptionMetadata.d = function (a) {
        FunnelSliceClickedEventArgsDescriptionMetadata.b(a);
        a.aa("FunnelSliceClickedEventArgs", function () { return new FunnelSliceClickedEventArgsDescription(); });
        a.z("FunnelSliceClickedEventArgs", FunnelSliceClickedEventArgsDescriptionMetadata.a);
    };
    FunnelSliceClickedEventArgsDescriptionMetadata.$t = markType(FunnelSliceClickedEventArgsDescriptionMetadata, 'FunnelSliceClickedEventArgsDescriptionMetadata');
    FunnelSliceClickedEventArgsDescriptionMetadata.a = null;
    return FunnelSliceClickedEventArgsDescriptionMetadata;
}(Base));
export { FunnelSliceClickedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/FunnelSliceClickedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceClickedEventArgsDescription } from "./FunnelSliceClickedEventArgsDescription";
/**
 * @hidden
 */
var FunnelSliceClickedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunnelSliceClickedEventArgsDescriptionMetadata, _super);
    function FunnelSliceClickedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelSliceClickedEventArgsDescriptionMetadata.b = function (a) {
        if (FunnelSliceClickedEventArgsDescriptionMetadata.a == null) {
            FunnelSliceClickedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelSliceClickedEventArgsDescriptionMetadata.c(FunnelSliceClickedEventArgsDescriptionMetadata.a);
        }
        if (a.k(FunnelSliceClickedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(FunnelSliceClickedEventArgsDescriptionMetadata.a);
    };
    FunnelSliceClickedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("Bounds", "Rect");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    FunnelSliceClickedEventArgsDescriptionMetadata.d = function (a) {
        FunnelSliceClickedEventArgsDescriptionMetadata.b(a);
        a.ac("FunnelSliceClickedEventArgs", function () { return new FunnelSliceClickedEventArgsDescription(); });
        a.ab("FunnelSliceClickedEventArgs", FunnelSliceClickedEventArgsDescriptionMetadata.a);
    };
    FunnelSliceClickedEventArgsDescriptionMetadata.$t = markType(FunnelSliceClickedEventArgsDescriptionMetadata, 'FunnelSliceClickedEventArgsDescriptionMetadata');
    FunnelSliceClickedEventArgsDescriptionMetadata.a = null;
    return FunnelSliceClickedEventArgsDescriptionMetadata;
}(Base));
export { FunnelSliceClickedEventArgsDescriptionMetadata };
